@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-'''konch: The customizable Python shell.
+'''konch: Customizes your Python shell.
 
 Usage:
   konch
@@ -33,7 +33,7 @@ import random
 
 from docopt import docopt
 
-__version__ = '0.3.0'
+__version__ = '0.3.1'
 __author__ = 'Steven Loria'
 __license__ = 'MIT'
 
@@ -139,10 +139,10 @@ class IPythonShell(Shell):
     def start(self):
         try:
             from IPython import embed
-            from IPython.config.loader import Config
+            from IPython.config.loader import Config as IPyConfig
         except ImportError:
             raise ShellNotAvailableError('IPython shell not available.')
-        ipy_config = Config()
+        ipy_config = IPyConfig()
         prompt_config = ipy_config.PromptManager
         if self.prompt:
             prompt_config.in_template = self.prompt
@@ -175,23 +175,21 @@ class AutoShell(Shell):
     Python shell.
     """
 
-    def __init__(self, context, banner=DEFAULT_BANNER_TEXT, *args, **kwargs):
-        self.context = context
+    def __init__(self, context, banner, *args, **kwargs):
+        Shell.__init__(self, context, *args, **kwargs)
         self.banner = banner
-        self.args = args
-        self.kwargs = kwargs
 
     def start(self):
         try:
             return IPythonShell(self.context, self.banner,
-                *self.args, **self.kwargs).start()
+                self.prompt, self.output).start()
         except ShellNotAvailableError:
             try:
                 return BPythonShell(self.context, self.banner,
-                    *self.args, **self.kwargs).start()
+                    self.prompt, self.output).start()
             except ShellNotAvailableError:
                 return PythonShell(self.context, self.banner,
-                    *self.args, **self.kwargs).start()
+                    self.prompt, self.output).start()
         return None
 
 
@@ -290,7 +288,6 @@ def config(config_dict):
     :param dict config_dict: Dict that may contain 'context', 'banner', and/or
         'shell' (default shell class to use).
     """
-    global cfg
     logger.debug('Updating with {0}'.format(config_dict))
     cfg.update(config_dict)
     return cfg
@@ -300,7 +297,6 @@ def named_config(name, config_dict):
     """Adds a named config to the config registry.
     This function should be called in a .konchrc file.
     """
-    global config_registry
     config_registry[name] = Config(**config_dict)
 
 
@@ -315,6 +311,8 @@ def get_file_directory(filename):
 
 
 def __ensure_directory_in_path(filename):
+    """Ensures that a file's directory is in the Python path.
+    """
     directory = get_file_directory(filename)
     if directory not in sys.path:
         logger.debug('Adding {0} to sys.path'.format(directory))
@@ -345,11 +343,13 @@ def resolve_path(filename):
     """Find a file by walking up parent directories until the file is found.
     Return the absolute path of the file.
     """
-    while os.getcwd() != __get_home_directory():
-        if os.path.exists(filename):
-            return os.path.abspath(filename)
+    current = os.getcwd()
+    while current != __get_home_directory():
+        target = os.path.join(current, filename)
+        if os.path.exists(target):
+            return os.path.abspath(target)
         else:
-            os.chdir(os.path.pardir)
+            current = os.path.join(current, '..')
     return False
 
 
@@ -369,7 +369,6 @@ def init_config(config_file=None):
 
 def main():
     """Main entry point for the konch CLI."""
-    global cfg
     args = docopt(__doc__, version=__version__)
     if args['--debug']:
         logging.basicConfig(
@@ -383,17 +382,17 @@ def main():
     use_file(args['--file'])
 
     if args['--name']:
-        config = config_registry.get(args['--name'], cfg)
+        config_dict = config_registry.get(args['--name'], cfg)
         logger.debug('Using named config...')
         logger.debug(config)
     else:
-        config = cfg
+        config_dict = cfg
     # Allow default shell to be overriden by command-line argument
     shell_name = args['--shell']
     if shell_name:
-        config['shell'] = SHELL_MAP.get(shell_name.lower(), AutoShell)
-    logger.debug('Starting with config {0}'.format(config))
-    start(**config)
+        config_dict['shell'] = SHELL_MAP.get(shell_name.lower(), AutoShell)
+    logger.debug('Starting with config {0}'.format(config_dict))
+    start(**config_dict)
     sys.exit(0)
 
 if __name__ == '__main__':
